# AWS-Machine-Learning-Foundation
# Mecha-distribution-package
This is a Bionomial distribution package

# Files

Explanation of each file in the package
# Installation

You can run the package by using __init__ file after extracting the package
